# RailsIbm

Welcome to your Rais IBM module! This gem intend to provide you some fetures used on IBM Web applications (IBM VPN is required). Right now this GEM only have the bluepages module, but it will store the SSO in the future.

## Code of Conduct

Everyone interacting in the RailsIbm::Uprofile project's codebases, issue trackers, chat rooms and mailing lists is expected to follow the [code of conduct](https://github.com/niightly/rails_ibm-uprofile/blob/master/CODE_OF_CONDUCT.md).

## Table of Contents

- [Installation](#isntallation)
- [Usage](#usage)
- [Method: info](#method-info)
- [Method: skills](#method-skills)
- [Method: teams](#method-teams)
- [Method: all](#method-all)
- [Contributing](#contributing)
- [License](#license)

## Installation

Add this line to your application's Gemfile:

```ruby
gem 'rails_ibm-uprofile'
```

And then execute:

    $ bundle install

Or install it yourself as:

    $ gem install rails_ibm-uprofile


# RailsIbm::Uprofile

This module allow you to fetch information from Bluepages directory (using the [Unified-profile](https://w3.ibm.com/w3publisher/bluepages-ui-support)).

## Usage

This module have different methods to search the users and provide different data:

### <a id="method-info"></a>#Info(args*: value[, options])

This module allos you to search one or more entries at time, it will return the information about the employee(s)

```ruby
require 'rails_ibm/uprofile'

RailsIbm::Uprofile.info(uid: '000000000')
```

#### Args*

Since there are different kind of ways to search the user and to ensure readability we split it in several alternatives. It is important to know that at least one of these args are __required__.

| name | value | Usage
| --- | --- | ---
| uid | String | `RailsIbm::Uprofile.info(uid: '000000000')`
| uids | Array | `RailsIbm::Uprofile.info(uids: ['000000000', '111111111'])`
| email | String | `RailsIbm::Uprofile.info(email: 'johndoe@ibm.com')`
| emails | Array | `RailsIbm::Uprofile.info(emails: ['johndoe@ibm.com', 'janedoe@ibm.com'])`
| query | String | `RailsIbm::Uprofile.info(query: 'John Doe')`

#### Options (`optional`)

| Attribure | Type | Default | Purpose
| --- | --- | --- | ---
| parsed | Boolean | true | Returns a [Parsed Object](#parsed-object)<br><sup>if __false__ Return a [BluepagesUnifiedProfileAPI](https://unified-profile-api.us-south-k8s.intranet.ibm.com/v3/api/) Object</sup>
| remap | Boolean | false | Returns a [Remapped Object](#remapped-object).<br><sup>This option is ignored if `parsed` is __true__</sup>
| serial | String | '000000' | Will increase the performance of the search by fetching first entries that are peers from the serial informed.<br><sup>Only available for __query__ arg.</sup>
| limit | Number | 10 | Will limit the result of the API in the number specified.<br><sup>Only available for __query__ arg.</sup>
| start | Number | 0 | Will start from this position of the list (common used for pagination).<br><sup>Only available for __query__ arg.</sup>
| array | Boolean | true | The result will be an array instead of an object.<br><sup>Only available for __query__ arg.</sup><br><sup>This option is ignored if `detailed` is __false__.</sup>

#### Schemas

These are the following models available in this API.

##### Parsed Object

###### UID
```ruby
{
    :"uid_#{query}": BluepagesUnifiedProfileAPI.content
}

# Ex.:
#    $ RailsIbm::Uprofile.info(uid: '000000000')
#    $ => { uid_000000000: BluepagesUnifiedProfileAPI.content }
```
>

###### Email
```ruby
{
    :"#{query}": BluepagesUnifiedProfileAPI.content
}

# Ex.:
#    $ RailsIbm::Uprofile.info(email: 'johndoe@ibm.com')
#    $ => { johndoe@ibm.com: BluepagesUnifiedProfileAPI.content }
```

##### Remapped Object

It will rewrite the object to a DefaultTemplate used by this module (preferred for authentications)

###### DefaultTemplate

```ruby
{
    uid: BluepagesUnifiedProfileAPI.content.uid,
    name: BluepagesUnifiedProfileAPI.content.nameFull,
    email: BluepagesUnifiedProfileAPI.content.preferredIdentity,
    shortname: BluepagesUnifiedProfileAPI.content.nameDisplay || BluepagesUnifiedProfileAPI.content.nameFull
}
```

###### UID
```ruby
{
    :"uid_#{query}": DefaultTemplate
}

# Ex.:
#    $ RailsIbm::Uprofile.info(uid: '000000000')
#    $ => { uid_000000000: ShortDataUserObject }
```
>

###### Email
```ruby
{
    :"#{query}": DefaultTemplate
}

# Ex.:
#    $ RailsIbm::Uprofile.info(email: 'johndoe@ibm.com')
#    $ => { johndoe@ibm.com: ShortDataUserObject }
```

### <a id="method-skills"></a>#Skills(args*: value)

This method only allows one search at time and it will return the skill set information of the employee.

```ruby
require 'rails_ibm/uprofile'

RailsIbm::Uprofile.skills(uid: '000000000')
```

This module have 2 variations, you can check the details below:

#### Args*

Since there are different kind of ways to search the user and to ensure readability we split it in several alternatives. It is important to know that at least one of these args are __required__.

| name | value | Usage
| --- | --- | ---
| uid | String | `RailsIbm::Uprofile.info(uid: '000000000')`
| email | String | `RailsIbm::Uprofile.info(email: 'johndoe@ibm.com')`

#### Schemas

There are no special remapping or parsing for this results, the schema can be checked on [BluepagesUnifiedProfileAPI](https://unified-profile-api.us-south-k8s.intranet.ibm.com/v3/api/) docs

### <a id="method-teams"></a>#Teams(args*: value)

This method only allows one search at time and it will return the peers and hierarchical tree of the employee (Inside and Outside the country)

```ruby
require 'rails_ibm/uprofile'

RailsIbm::Uprofile.skills(uid: '000000000')
```

This module have 2 variations, you can check the details below:

#### Args*

Since there are different kind of ways to search the user and to ensure readability we split it in several alternatives. It is important to know that at least one of these args are __required__.

| name | value | Usage
| --- | --- | ---
| uid | String | `RailsIbm::Uprofile.info(uid: '000000000')`
| email | String | `RailsIbm::Uprofile.info(email: 'johndoe@ibm.com')`

#### Schemas

There are no special remapping or parsing for this results, the schema can be checked on [BluepagesUnifiedProfileAPI](https://unified-profile-api.us-south-k8s.intranet.ibm.com/v3/api/) docs

### <a id="method-all"></a>#all(args*: value)

This method only allows one search at time and it will return the peers and hierarchical tree of the employee (Inside and Outside the country)

```ruby
require 'rails_ibm/uprofile'

RailsIbm::Uprofile.skills(uid: '000000000')
```

This module have 2 variations, you can check the details below:

#### Args*

Since there are different kind of ways to search the user and to ensure readability we split it in several alternatives. It is important to know that at least one of these args are __required__.

| name | value | Usage
| --- | --- | ---
| uid | String | `RailsIbm::Uprofile.info(uid: '000000000')`
| email | String | `RailsIbm::Uprofile.info(email: 'johndoe@ibm.com')`

#### Schemas

There are no special remapping or parsing for this results, the schema can be checked on [BluepagesUnifiedProfileAPI](https://unified-profile-api.us-south-k8s.intranet.ibm.com/v3/api/) docs

## Tests

I'm in shame to do this, but since I was in a hurry, we got some testers to verify this project, and I know I should implement some automated tests. But this module were created for a project and because of this I had to do this way.

## Contributing

Bug reports and pull requests are welcome on GitHub at https://github.com/niightly/rails_ibm-uprofile. This project is intended to be a safe, welcoming space for collaboration, and contributors are expected to adhere to the [code of conduct](https://github.com/niightly/rails_ibm-uprofile/blob/master/CODE_OF_CONDUCT.md).

## License

The gem is available as open source under the terms of the [MIT License](https://opensource.org/licenses/MIT).
